// KreateCD - CD recording software for the K desktop environment
//
// 1999 by Alexander Feigl <Alexander.Feigl@gmx.de>
//
// This file is subject to the terms and conditions of the GNU General      
// Public License.  See the file COPYING in the main directory of the       
// KreateCD distribution for more details.                                     

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <qmessagebox.h>
#include <klocale.h>

extern KLocale *locale;

#define KREATECD_VERSION "KreateCD " VERSION

void showAbout(void)
 {
  QMessageBox *qmsg;
  char abouttext[2048];

  strcpy(abouttext,KREATECD_VERSION "\n\n");
  strcat(abouttext,
  locale->translate(
  "1998-1999 by Alexander Feigl\n\n"
  "Alexander Feigl\n"
  "Burachstrasse 51\n"
  "88250 Weingarten\n\n"
  "Alexander.Feigl@gmx.de\n\n"
  "This software is distributed under the\nGNU Public License! Hope youll enjoy it!\n"));
 
  qmsg=new QMessageBox(KREATECD_VERSION,abouttext,QMessageBox::Information,QMessageBox::Ok,0,0);
  qmsg->setButtonText(QMessageBox::Ok,locale->translate("Great!"));
  qmsg->show();
 }
